@@ -1,10 +1,13 @@
 class Logger:
 
-    def log(self, message):
+    @staticmethod
+    def log(message):
         print(f'Log - {message}')
 
-    def error(self, message):
+    @staticmethod
+    def error(message):
         print(f'Error - {message}')
 
-    def debug(self, message):
-        print(f'debug - {message}')
\ No newline at end of file
+    @staticmethod
+    def debug(message):
+        print(f'debug - {message}')
