@@ -5,6 +5,7 @@ from selenium.common.exceptions import NoSuchElementException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.webelement import WebElement as SeleniumWebElement
 
+from Samuranium.Config import Config
 from Samuranium.utils.classes import get_class_variables_dict
 from Samuranium.utils.time import get_current_time
 
@@ -15,11 +16,12 @@ class WebElement:
     """
 
     def __init__(self, samuranium_instance, selector, exact_selector=False, max_wait_time=None):
+        self.config = Config()
         self.browser = samuranium_instance.driver
         self.logger = samuranium_instance.logger
         self.selector = selector
         self.exact_selector = exact_selector
-        self.max_wait_time = max_wait_time if max_wait_time else float(5)
+        self.max_wait_time = max_wait_time if max_wait_time else self.config.default_wait_time
         self.__element = None
 
     @property
@@ -56,7 +58,10 @@ class WebElement:
     def __xpath_strategies():
         return {'match_xpath': '{}', 'exact_text': '//*[text()="{}"]',
                 'normalize_text': '//*[not(self::script)][text()[normalize-space()="{}"]]',
-                'contains_text': '//*[not(self::script)][contains(text(),"{}")]'}
+                'contains_text': '//*[not(self::script)][contains(text(),"{}")]',
+                'normalize_contains_text':
+                    '//*[not(self::script)][contains(normalize-space(.), "{}")]',
+                }
 
     @staticmethod
     def __css_strategies():
@@ -85,6 +90,8 @@ class WebElement:
                         return element
                 except NoSuchElementException:
                     pass
+        self.logger.error(f'Element with selector: {self.selector} was not found after '
+                          f'{self.max_wait_time}')
         return None
 
     def __find_by_xpath(self):
